algolia_client_core library
Core functionality for interacting with the Algolia API.
This library provides the essential logic for configuring and executing HTTP requests to the Algolia API. It includes support for retry strategies and comprehensive exception handling.
Classes
- AgentSegment
- Represents a segment of algolia agent header.
- AlgoliaNoResponse
- Represents a successful API response with no content (HTTP 204).
- ApiClient
- An abstract class representing an API client with specific properties and options.
- ApiRequest
- Represents an API request to be sent to Algolia.
- ChunkedHelperOptions
- Optional configuration for chunked helpers that batch records and poll for task completion.
- ClientOptions
- Host
- Represents an Algolia host.
- HttpRequest
- Represents an Http request.
- HttpResponse
- Represents an Http response
- Requester
- A contract Requester to define an interface for handling HTTP requests and responses.
- RequestOptions
- Represents options for configuring a request to an endpoint.
- RetryStrategy
- Component to run http requests with retry logic.
- TransformationOptions
-
Options for the ingestion transporter used by
*WithTransformationhelpers.
Enums
- CallType
- Indicate whether the HTTP call performed is of type read (GET) or write (POST, PUT ..). Used to determine which timeout duration to use.
- RequestMethod
- Provides enumerated HTTP verbs
Constants
- defaultMaxRetries → const int
- Default maximum number of retries for chunked helpers and wait operations.
- defaultReplaceAllObjectsMaxRetries → const int
-
Default maximum number of retries used by
replaceAllObjects.
Exceptions / Errors
- AlgoliaApiException
- Exception thrown when the Algolia API returns an error.
- AlgoliaException
- Abstract base class for all Algolia exceptions.
- AlgoliaIOException
- Exception thrown when there is an input/output error during a request to the Algolia API.
- AlgoliaTimeoutException
- Exception thrown when a request to the Algolia API times out.
- AlgoliaWaitException
- Exception thrown when an error occurs during the wait strategy. For example: maximum number of retry exceeded.
- UnreachableHostsException
- Exception thrown when all hosts for the Algolia API are unreachable.