writeTimeout property

Duration writeTimeout
final

The maximum duration to wait for a write operation to complete before timing out.

Defaults to unsetTimeout, meaning the per-client default from the spec is applied by the transport; set it explicitly to override.

Implementation

final Duration writeTimeout;